@@ -312,7 +312,7 @@ impl Device for FileDevice {
     }
 
     fn trim_end_pages(&self, update_list: &mut dyn UpdateList) -> PERes<()> {
-        while check_and_trim(&mut self.file.lock()?.file, update_list)? {}
+        while check_and_trim(&mut self.file.lock()?.file, update_list, false)? {}
         Ok(())
     }
 }
