@@ -4,10 +4,10 @@ use crate::{
     index::{
         bytevec::ByteVec,
         config::{IndexOrd, IndexTypeInternal, Indexes, ValueMode},
-        serialization::{deserialize, serialize},
+        serialization::{deserialize, reuse_deserialize, serialize},
         string_wrapper::StringWrapper,
         tree::{
-            nodes::{compare, Node, NodeRef, PageIter, PageIterBack, Value},
+            nodes::{compare, Node, NodeRef, Nodes, PageIter, PageIterBack, Value},
             IndexApply, KeyChanges, ValueChange as TreeValue,
         },
     },
@@ -442,6 +442,7 @@ impl IndexTransactionKeeper {
 
 pub trait IndexKeeper<K, V> {
     fn load(&self, node: &NodeRef) -> PERes<Node<K, V>>;
+    fn load_with(&self, node: &NodeRef, reuse: Option<Nodes<K>>) -> PERes<Node<K, V>>;
     fn get_root(&self) -> PERes<Option<NodeRef>>;
     fn value_mode(&self) -> ValueMode;
     fn index_name(&self) -> &String;
@@ -509,6 +510,14 @@ impl<'a, K: IndexTypeInternal, V: IndexTypeInternal> IndexKeeper<K, V> for Index
             .unwrap();
         Ok(rec)
     }
+    fn load_with(&self, node: &NodeRef, reuse: Option<Nodes<K>>) -> PERes<Node<K, V>> {
+        let rec = self
+            .store
+            .read_snap_fn(self.segment, node, self.snapshot, |e| reuse_deserialize(e, reuse))
+            .map_err(map_read_err)?
+            .unwrap();
+        Ok(rec)
+    }
     fn get_root(&self) -> PERes<Option<NodeRef>> {
         Ok(self.root)
     }
@@ -755,6 +764,9 @@ impl<'a, K: IndexTypeInternal, V: IndexTypeInternal> IndexKeeper<K, V> for Index
             .unwrap();
         Ok(rec)
     }
+    fn load_with(&self, node: &NodeRef, _reuse: Option<Nodes<K>>) -> PERes<Node<K, V>> {
+        self.load(node)
+    }
     fn get_root(&self) -> PERes<Option<NodeRef>> {
         Ok(self.root)
     }
